@@ -5,12 +5,13 @@ else
 end
 ActsAsTaggableOnMigration.class_eval do
   def self.up
-    create_table :tags do |t|
+    create_table ActsAsTaggableOn.tags_table do |t|
       t.string :name
+      t.timestamps
     end
 
-    create_table :taggings do |t|
-      t.references :tag
+    create_table ActsAsTaggableOn.taggings_table do |t|
+      t.references :tag, foreign_key: { to_table: ActsAsTaggableOn.tags_table }
 
       # You should make sure that the column created is
       # long enough to store the required class names.
@@ -24,12 +25,12 @@ ActsAsTaggableOnMigration.class_eval do
       t.datetime :created_at
     end
 
-    add_index :taggings, :tag_id
-    add_index :taggings, [:taggable_id, :taggable_type, :context]
+    add_index ActsAsTaggableOn.taggings_table, :tag_id
+    add_index ActsAsTaggableOn.taggings_table, [:taggable_id, :taggable_type, :context], name: 'taggings_taggable_context_idx'
   end
 
   def self.down
-    drop_table :taggings
-    drop_table :tags
+    drop_table ActsAsTaggableOn.taggings_table
+    drop_table ActsAsTaggableOn.tags_table
   end
 end
