@@ -5,15 +5,15 @@ else
 end
 AddTaggingsCounterCacheToTags.class_eval do
   def self.up
-    add_column :tags, :taggings_count, :integer, default: 0
+    add_column ActsAsTaggableOn.tags_table, :taggings_count, :integer, default: 0
 
     ActsAsTaggableOn::Tag.reset_column_information
     ActsAsTaggableOn::Tag.find_each do |tag|
-      ActsAsTaggableOn::Tag.reset_counters(tag.id, :taggings)
+      ActsAsTaggableOn::Tag.reset_counters(tag.id, ActsAsTaggableOn.taggings_table)
     end
   end
 
   def self.down
-    remove_column :tags, :taggings_count
+    remove_column ActsAsTaggableOn.tags_table, :taggings_count
   end
 end
