@@ -1,12 +1,12 @@
 ActiveRecord::Schema.define version: 0 do
-  create_table :tags, force: true do |t|
+  create_table ActsAsTaggableOn.tags_table, force: true do |t|
     t.string :name
     t.integer :taggings_count, default: 0
     t.string :type
   end
-  add_index 'tags', ['name'], name: 'index_tags_on_name', unique: true
+  add_index ActsAsTaggableOn.tags_table, ['name'], name: 'index_tags_on_name', unique: true
 
-  create_table :taggings, force: true do |t|
+  create_table ActsAsTaggableOn.taggings_table, force: true do |t|
     t.integer :tag_id
 
     # You should make sure that the column created is
@@ -23,10 +23,10 @@ ActiveRecord::Schema.define version: 0 do
 
     t.datetime :created_at
   end
-  add_index 'taggings',
+  add_index ActsAsTaggableOn.taggings_table,
             ['tag_id', 'taggable_id', 'taggable_type', 'context', 'tagger_id', 'tagger_type'],
             unique: true, name: 'taggings_idx'
-  add_index 'taggings', :tag_id , name: 'index_taggings_on_tag_id'
+  add_index ActsAsTaggableOn.taggings_table, :tag_id , name: 'index_taggings_on_tag_id'
 
   # above copied from
   # generators/acts_as_taggable_on/migration/migration_generator
@@ -36,6 +36,12 @@ ActiveRecord::Schema.define version: 0 do
     t.column :type, :string
   end
 
+  create_table :columns_override_models, force: true do |t|
+    t.column :name, :string
+    t.column :type, :string
+    t.column :ignored_column, :string
+  end
+
   create_table :non_standard_id_taggable_models, primary_key: 'an_id', force: true do |t|
     t.column :name, :string
     t.column :type, :string
